@@ -26,12 +26,11 @@ from .filtering.filt_obj import filt
 from .filtering.signal_optimiser import signal_optimiser, optimisation_plot
 
 from .helpers import plot
-from .helpers.helpers import (bool_2_indices, rolling_window, Bunch,
-                              calc_grads, unitpicker, findmins, stack_keys,
-                              analyte_checker)
-from .helpers.analyte_names import pretty_element, analyte_sort_fn
+from .helpers.utils import Bunch
+from .helpers.signal import bool_2_indices, rolling_window, calc_grads, findmins
+from .helpers.analytes import pretty_element, analyte_sort_fn, unitpicker, analyte_checker
 from .helpers.logging import _log
-from .helpers.stat_fns import nominal_values, std_devs, unpack_uncertainties, nan_pearsonr
+from .helpers.stat_fns import nominal_values, std_devs, unpack_uncertainties, nan_pearsonr, stack_keys
 from .helpers.chemistry import to_mass_fraction, analyte_mass
 
 # TODO: Neat way to get data with filters applied
@@ -127,7 +126,8 @@ class D(object):
 
         # set for recording calculated ratios
         self.analyte_ratios = set()
-
+        self.uncalibrated = set()
+        
         # calculate total counts
         self.data['total_counts'] = sum(self.data['rawdata'].values())
 
@@ -175,14 +175,14 @@ class D(object):
 
         return
 
-    def _analyte_checker(self, analytes=None, check_ratios=True, single=False):
+    def _analyte_checker(self, analytes=None, check_ratios=True, single=False, focus_stage=None):
         """
         Return valid analytes depending on the analysis stage
         """
-        return analyte_checker(self, analytes=analytes, check_ratios=check_ratios, single=single)
+        return analyte_checker(self, analytes=analytes, check_ratios=check_ratios, single=single, focus_stage=focus_stage)
 
-    def analytes_sorted(self, a=None, check_ratios=True):
-        return sorted(self._analyte_checker(a, check_ratios=check_ratios), key=analyte_sort_fn)
+    def analytes_sorted(self, analytes=None, check_ratios=True, single=False, focus_stage=None):
+        return sorted(self._analyte_checker(analytes=analytes, check_ratios=check_ratios, single=single, focus_stage=focus_stage), key=analyte_sort_fn)
 
     def _init_filts(self, analytes):
         self.filt = filt(self.Time.size, analytes)
@@ -355,7 +355,7 @@ class D(object):
         (self.bkg, self.sig,
          self.trn, failed) = proc.autorange(self.Time, sig, gwin=gwin, swin=swin, win=win,
                                             on_mult=on_mult, off_mult=off_mult,
-                                            transform=transform)
+                                            transform=transform, **kwargs)
 
         self.mkrngs()
 
@@ -374,7 +374,7 @@ class D(object):
             #                "everything is OK.\n"))
 
         if ploterrs and errs_to_plot and len(plotlines) > 0:
-            f, ax = self.tplot(ranges=True)
+            f, ax = self.trace_plot(ranges=True)
             for pl in plotlines:
                 ax.axvline(pl, c='r', alpha=0.6, lw=3, ls='dashed')
             return f, plotlines
@@ -503,7 +503,7 @@ class D(object):
         self.data['bkgsub'][target_analyte] -= self.data['bkgsub'][source_analyte] * f
 
     @_log
-    def ratio(self, internal_standard=None, analytes=None):
+    def ratio(self, internal_standard=None, analytes=None, focus_stage='bkgsub', newfilter_mode='all'):
         """
         Divide all analytes by a specified internal_standard analyte.
 
@@ -519,22 +519,44 @@ class D(object):
         if internal_standard is not None:
             self.internal_standard = internal_standard
         
-        if analytes is None:
-            analytes = self.analytes
-        elif isinstance(analytes, str):
-            analytes = [analytes]
+        # deal with ratio calculation from other ratios
+        existing_ratios = False
+        if '_' in self.internal_standard:
+            existing_ratios = True
+        if focus_stage == 'bkgsub':
+            target_stage = 'ratios'
+        else:
+            target_stage = focus_stage
+
+        analytes = self._analyte_checker(analytes, focus_stage=focus_stage)
+        
+        # if analytes is None:
+        #     analytes = self.analytes
+        # elif isinstance(analytes, str):
+        #     analytes = [analytes]
         
         if 'ratios' not in self.data.keys():
             self.data['ratios'] = Bunch()
         for a in analytes:
-            if a == internal_standard:
+            if a == self.internal_standard:
                 continue
-            analyte_ratio = f'{a}_{self.internal_standard}'
-            self.data['ratios'][analyte_ratio] = (self.data['bkgsub'][a] /
-                                      self.data['bkgsub'][self.internal_standard])
+            
+            if existing_ratios: 
+                num = a.split('_')[0]
+                denom = self.internal_standard.split('_')[0]
+                analyte_ratio = f'{num}_{denom}'
+            else:
+                analyte_ratio = f'{a}_{self.internal_standard}'
+            
+            self.data[target_stage][analyte_ratio] = (self.data[focus_stage][a] /
+                                      self.data[focus_stage][self.internal_standard])
             self.analyte_ratios.update([analyte_ratio])
             self.cmap[analyte_ratio] = self.cmap[a]
-        self.setfocus('ratios')
+
+            if self.filt is not None:
+                self.filt.add_to_table(analyte_ratio, mode=newfilter_mode)
+        
+            self.setfocus(target_stage)
         return
 
     @_log
@@ -584,7 +606,7 @@ class D(object):
         if analyte_masses is None:
             analyte_masses = analyte_mass(self.analytes)
         
-        if np.isnan(internal_standard_conc):
+        if np.isnan(un.nominal_values(internal_standard_conc)):
             for a in analytes:
                 num, denom = a.split('_')
                 self.data['mass_fraction'][num] = np.full(self.data['calibrated'][a].shape, np.nan)
@@ -634,7 +656,7 @@ class D(object):
         -------
         None
         """
-        analytes = self._analyte_checker(analytes)
+        analytes = self._analyte_checker(analytes, focus_stage=focus_stage)
 
         self.stats = Bunch()
         self.stats['analytes'] = analytes
@@ -1360,12 +1382,12 @@ class D(object):
         overlay_alpha : float
             The opacity of the threshold overlays. Between 0 and 1.
         **kwargs
-            Passed to `tplot`
+            Passed to `trace_plot`
         """
         return optimisation_plot(self, overlay_alpha=0.5, **kwargs)
 
     @_log
-    def tplot(self, analytes=None, figsize=[10, 4], scale='log', filt=None,
+    def trace_plot(self, analytes=None, figsize=[10, 4], scale='log', filt=None,
               ranges=False, stats=False, stat='nanmean', err='nanstd',
               focus_stage=None, err_envelope=False, ax=None):
         """
@@ -1401,7 +1423,7 @@ class D(object):
         figure, axis
         """
 
-        return plot.tplot(self=self, analytes=analytes, figsize=figsize, scale=scale, filt=filt,
+        return plot.trace_plot(self=self, analytes=analytes, figsize=figsize, scale=scale, filt=filt,
                           ranges=ranges, stats=stats, stat=stat, err=err,
                           focus_stage=focus_stage, err_envelope=err_envelope, ax=ax)
 
