@@ -11,13 +11,13 @@ LAtools: a data analysis package for the reproducible reduction of LA-ICPMS data
 
 from .latools import analyse, reproduce
 from .latools import analyse as analyze  # for the yanks
-from .helpers.helpers import get_example_data
+from .helpers.utils import get_example_data
 from .helpers.stat_fns import nominal_values, std_devs
 from .helpers import config
 from .helpers import chemistry
 from . import preprocessing
 
-__version__ = '0.3.21'
+__version__ = '0.3.24'
 
 def cite(output='text'):
     """
