@@ -10,13 +10,13 @@ import matplotlib.pyplot as plt
 import matplotlib as mpl
 from scipy.stats import gaussian_kde
 from scipy.optimize import curve_fit
-from IPython import display
+# from IPython import display
 from pandas import IndexSlice as idx
 
 from tqdm import tqdm
 
-from .helpers import fastgrad, fastsmooth, findmins, bool_2_indices, rangecalc, unitpicker, calc_grads
-from .analyte_names import pretty_element
+from .signal import fastgrad, fastsmooth, findmins, bool_2_indices, calc_grads
+from .analytes import pretty_element, unitpicker, analyte_checker
 from .stat_fns import nominal_values, gauss, R2calc, unpack_uncertainties
 
 def calc_nrow(n, ncol):
@@ -26,8 +26,14 @@ def calc_nrow(n, ncol):
         nrow = n // ncol + 1
     
     return int(nrow)
+
+def rangecalc(xs, pad=0.05):
+    mn = np.nanmin(xs)
+    mx = np.nanmax(xs)
+    xr = mx - mn
+    return [mn - pad * xr, mx + pad * xr]
     
-def tplot(self, analytes=None, figsize=[10, 4], scale='log', filt=None,
+def trace_plot(self, analytes=None, figsize=[10, 4], scale='log', filt=None,
               ranges=False, stats=False, stat='nanmean', err='nanstd',
               focus_stage=None, err_envelope=False, ax=None):
         """
@@ -65,10 +71,12 @@ def tplot(self, analytes=None, figsize=[10, 4], scale='log', filt=None,
         if focus_stage is None:
             focus_stage = self.focus_stage
 
-        if analytes is None:
-            analytes = self.analytes        
-            if focus_stage in ['ratios', 'calibrated']:
-                analytes = self.analyte_ratios
+        # TODO: This is broken. conflict between manually specified focus_stage and analytes provided by D_obj
+        analytes = analyte_checker(self, analytes, focus_stage=focus_stage)
+        # if analytes is None:
+            # analytes = self.analytes        
+            # if focus_stage in ['ratios', 'calibrated']:
+            #     analytes = self.analyte_ratios
 
         if ax is None:
             fig = plt.figure(figsize=figsize)
@@ -79,6 +87,9 @@ def tplot(self, analytes=None, figsize=[10, 4], scale='log', filt=None,
             ret = False
 
         for a in analytes:
+            if a not in self.data[focus_stage]:
+                continue
+                # TODO: this is lazy and will fail silently. Should print a warning.
             x = self.Time
             y, yerr = unpack_uncertainties(self.data[focus_stage][a])
 
@@ -270,7 +281,7 @@ def gplot(self, analytes=None, win=25, figsize=[10, 4], filt=False,
             return fig, ax
 
 def crossplot(dat, keys=None, lognorm=True, bins=25, figsize=(12, 12),
-              colourful=True, focus_stage=None, denominator=None,
+              colourful=True, focus_stage=None,
               mode='hist2d', cmap=None, **kwargs):
     """
     Plot analytes against each other.
@@ -340,7 +351,7 @@ def crossplot(dat, keys=None, lognorm=True, bins=25, figsize=(12, 12),
     # determine units for all keys
     udict = {a: unitpicker(np.nanmean(focus[a]),
                            focus_stage=focus_stage,
-                           denominator=denominator) for a in keys}
+                           label=a) for a in keys}
     # determine ranges for all analytes
     rdict = {a: (np.nanmin(focus[a] * udict[a][0]),
                  np.nanmax(focus[a] * udict[a][0])) for a in keys}
@@ -395,9 +406,10 @@ def crossplot(dat, keys=None, lognorm=True, bins=25, figsize=(12, 12),
 
     # diagonal labels
     for a, n in zip(keys, np.arange(len(keys))):
-        axes[n, n].annotate(a + '\n' + udict[a][1], (0.5, 0.5),
+        label = udict[a][1].split(' ')
+        axes[n, n].annotate('\n'.join(label[::-1]), (0.5, 0.5),
                             xycoords='axes fraction',
-                            ha='center', va='center', fontsize=8)
+                            ha='center', va='center', fontsize=10)
         axes[n, n].set_xlim(*rdict[a])
         axes[n, n].set_ylim(*rdict[a])
     # switch on alternating axes
@@ -445,12 +457,13 @@ def histograms(dat, keys=None, bins=25, logy=False, cmap=None, ncol=4):
     for k, ax in zip(keys, axs.flat):
         tmp = nominal_values(dat[k])
         x = tmp[~np.isnan(tmp)]
+        m, u = unitpicker(x)
 
         if cmap is not None:
             c = cmap[k]
         else:
             c = (0, 0, 0, 0.5)
-        ax.hist(x, bins=bins, color=c)
+        ax.hist(x * m, bins=bins, color=c)
 
         if logy:
             ax.set_yscale('log')
@@ -1080,8 +1093,7 @@ def filter_report(Data, filt=None, analytes=None, savedir=None, nbin=5):
             yh = y[~np.isnan(y)]
 
             m, u = unitpicker(np.nanmax(y),
-                            denominator=Data.internal_standard,
-                            focus_stage=Data.focus_stage)
+                              focus_stage=Data.focus_stage)
 
             axs = tax, hax = (fig.add_axes([.1, .9 - (i + 1) * h, .6, h * .98]),
                             fig.add_axes([.7, .9 - (i + 1) * h, .2, h * .98]))
